[vim-addon-manager] 01/03: Various spelling fixes

James McCoy jamessan at debian.org
Mon Jul 11 16:28:35 UTC 2016


This is an automated email from the git hooks/post-receive script.

jamessan pushed a commit to branch master
in repository vim-addon-manager.

commit d1eac0baff39a3156e7e017d656c1b143efaa02f
Author: James McCoy <jamessan at jamessan.com>
Date:   Sat Jul 9 19:31:43 2016 -0400

    Various spelling fixes
    
    Signed-off-by: James McCoy <jamessan at jamessan.com>
---
 bin/vim-addon-manager                |  2 +-
 doc/addon-directory.markdown         |  4 ++--
 doc/registry-format.txt              |  4 ++--
 lib/vim/addon_manager/addon.rb       | 12 ++++++------
 spec/vim/addon_manager/addon_spec.rb |  2 +-
 5 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/bin/vim-addon-manager b/bin/vim-addon-manager
index 67e3802..5ab119a 100755
--- a/bin/vim-addon-manager
+++ b/bin/vim-addon-manager
@@ -177,7 +177,7 @@ Options:
   -t, --target-dir    set the addons target directory
                         (default: $HOME/.vim)
   -v, --verbose       increase verbosity
-  -z, --silent        silent mode: supress most of the output
+  -z, --silent        silent mode: suppress most of the output
   -y, --system-dir    set the system-wide target directory
                         (default: /var/lib/vim/addons)
   -w, --system-wide   set target directory to the system-wide one
diff --git a/doc/addon-directory.markdown b/doc/addon-directory.markdown
index 44116ed..bbde3a9 100644
--- a/doc/addon-directory.markdown
+++ b/doc/addon-directory.markdown
@@ -40,7 +40,7 @@ can contain subdirectories doc/, plugin/, autoload/, syntax/, etc. For example,
 These files were previously installed directly into /usr/share/vim/addons, and
 they are now being installed to /usr/share/vim/addons/vam/rails.
 
-When such an addon is installed vim `vim-addon-manager install rails`, you will
+When such an addon is installed via `vim-addon-manager install rails`, you will
 end up with a symlink at ~/.vim/vam/rails pointing at
 /usr/share/vim/addons/vam/rails. That symlink will be added to the vim
 runtimepath during startup.
@@ -62,7 +62,7 @@ format, follow these steps:
 * change the package to install to /usr/share/vim/addons/vam/$(addon) instead
   of scatering its files into /usr/share/vim/addons.
 
-During package upgrades, a dpkg trigger vim vim-addon-manager will remove the
+During package upgrades, a dpkg trigger via vim-addon-manager will remove the
 existing multiple symlinks from the target directory and install the new
 symlink into $(target\_dir)/vam.
 
diff --git a/doc/registry-format.txt b/doc/registry-format.txt
index 6c07bf7..2de34eb 100644
--- a/doc/registry-format.txt
+++ b/doc/registry-format.txt
@@ -62,7 +62,7 @@ the YAML specification:
     will be added to vim's runtimepath. This is the recommended addon type; see
     addon-directory.markdown for details.
 
-    If the "type" field is ommitted, it is assumed "legacy". This is to keep
+    If the "type" field is omitted, it is assumed "legacy". This is to keep
     backwards compatibility with previous addons.
 
   files:
@@ -75,7 +75,7 @@ the YAML specification:
   directory:
 
     for addons of type "directory", this field should indicate the directory in
-    which the addon is installed. If ommitted, it is assumed the addon is
+    which the addon is installed. If omitted, it is assumed the addon is
     installed to a subdirectory of /usr/share/vim/addons/vam.
 
   legacy_files:
diff --git a/spec/vim/addon_manager/addon_spec.rb b/spec/vim/addon_manager/addon_spec.rb
index b16ed7f..00382d3 100644
--- a/spec/vim/addon_manager/addon_spec.rb
+++ b/spec/vim/addon_manager/addon_spec.rb
@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe Vim::AddonManager::Addon do
 
-  it 'should build legacy addon objects if files atribute is specified' do
+  it 'should build legacy addon objects if files attribute is specified' do
     expect(addon('foo')).to be_a(Vim::AddonManager::Addon::Legacy)
   end
 

diff --git a/lib/vim/addon_manager/addon.rb b/lib/vim/addon_manager/addon.rb
index 4291571..c2f7a7e 100644
--- a/lib/vim/addon_manager/addon.rb
+++ b/lib/vim/addon_manager/addon.rb
@@ -39,7 +39,7 @@ module Vim
 
       # Returns a Set of the files contained in this addon.
       #
-      # This method must be overriden by subclasses.
+      # This method must be overridden by subclasses.
       #
       def files
         Set.new
@@ -53,12 +53,12 @@ module Vim
       #  * :installed (the addon is completely installed)
       #  * :broken (the addon is only partially installed)
       #  * :unavailable (source files are missing)
       #  * :unkonwn (the addon is unkonwn to the system)
       #
-      # This method must be overriden by subclasses.
+      # This method must be overridden by subclasses.
       #
       def status(target_dir)
-        AddonStatus.new :unkonwn
+        AddonStatus.new :unknown
       end
 
       def mkdir(dest)
@@ -73,7 +73,7 @@ module Vim
       # Installs addon files into +target_dir+ and returns a list of installed
       # files.
       #
-      # This method must be overriden by subclasses.
+      # This method must be overridden by subclasses.
       #
       def install(target_dir)
         []
@@ -82,7 +82,7 @@ module Vim
       # Removes addon files from +target_dir+ and returns a list of installed
       # files.
       #
-      # This method must be overriden by subclasses.
+      # This method must be overridden by subclasses.
       #
       def remove(target_dir)
         []
@@ -53,12 +53,12 @@ module Vim
       #  * :broken (the addon is only partially installed)
       #  * :unavailable (source files are missing)
-      #  * :unkonwn (the addon is unkonwn to the system)
+      #  * :unknown (the addon is unknown to the system)
       #
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-vim/vim-addon-manager.git



More information about the pkg-vim-maintainers mailing list